@@ -86,7 +86,6 @@ cv.glmreg_fit <- function(x, y, weights, lambda=NULL, balance=TRUE,
         else all.folds <- cv.folds(length(y), K)
     }
     else all.folds <- foldid
-    fraction <- seq(nlambda)
     registerDoParallel(cores=n.cores)
     i <- 1  ###needed to pass R CMD check with parallel code below
     residmat <- foreach(i=seq(K), .combine=cbind) %dopar% {
@@ -97,7 +96,7 @@ cv.glmreg_fit <- function(x, y, weights, lambda=NULL, balance=TRUE,
     cv <- apply(residmat, 1, mean)
     cv.error <- sqrt(apply(residmat, 1, var)/K)
     lambda.which <- which.max(cv)
-    obj<-list(fit=glmreg.obj, residmat=residmat, fraction = fraction, cv = cv, cv.error = cv.error, foldid=all.folds, lambda.which= lambda.which, lambda.optim = lambda[lambda.which])
+    obj<-list(fit=glmreg.obj, residmat=residmat, lambda = lambda, cv = cv, cv.error = cv.error, foldid=all.folds, lambda.which= lambda.which, lambda.optim = lambda[lambda.which])
     if(plot.it) plot.cv.glmreg(obj,se=se)
     class(obj) <- "cv.glmreg"
     obj
@@ -105,14 +104,14 @@ cv.glmreg_fit <- function(x, y, weights, lambda=NULL, balance=TRUE,
 
 "plot.cv.glmreg" <-
     function(x,se=TRUE,ylab=NULL, main=NULL, width=0.02, col="darkgrey", ...){
-        fraction <- x$fraction
+        lambda <- x$lambda
         cv <- x$cv
         cv.error <- x$cv.error
         if(is.null(ylab))
             ylab <- "log-likelihood"
-        plot(log(fraction), cv, type = "b", xlab = expression(log(lambda)), ylab= ylab, ylim = range(cv, cv + cv.error, cv - cv.error), main=main)
+        plot(log(lambda), cv, type = "b", xlab = expression(log(lambda)), ylab= ylab, ylim = range(cv, cv + cv.error, cv - cv.error), main=main)
         if(se)
-            error.bars(log(fraction), cv + cv.error, cv - cv.error,
+            error.bars(log(lambda), cv + cv.error, cv - cv.error,
                        width = width, col=col)
 
         invisible()
